API reference
==============

API components that most users will interact with.

**Content**

* `Echoregions Core Functions`_
* `Echoregions Lines`_
* `Echoregions Regions2D`_

Echoregions Core Functions
---------------
.. automodapi:: echoregions
   :no-inheritance-diagram:
   :no-heading:

Echoregions Lines
-----------------
.. automodapi:: echoregions.lines
   :no-inheritance-diagram:
   :no-heading:

Echoregions Regions2D
---------------------
.. automodapi:: echoregions.regions2d
   :no-inheritance-diagram:
   :no-heading:
